@@ -40,6 +40,7 @@ const Global = imports.global;
 const Main = imports.main;
 const MainWindow = imports.mainWindow;
 const Manager = imports.manager;
+const Notifications = imports.notifications;
 const OffsetController = imports.offsetController;
 const Path = imports.path;
 const Query = imports.query;
@@ -86,15 +87,22 @@ Application.prototype = {
 	    }));
 	this.application.add_action(quitAction);
 
+        let aboutAction = new Gio.SimpleAction({ name: 'about' });
+        aboutAction.connect('activate', Lang.bind(this,
+            function() {
+                this._mainWindow.showAbout();
+            }));
+        this.application.add_action(aboutAction);
+
         let fsAction = new Gio.SimpleAction({ name: 'fullscreen' });
         fsAction.connect('activate', Lang.bind(this,
             function() {
                 Global.modeController.toggleFullscreen();
             }));
-        Global.modeController.connect('window-mode-changed', Lang.bind(this,
+        Global.modeController.connect('can-fullscreen-changed', Lang.bind(this,
             function() {
-                let mode = Global.modeController.getWindowMode();
-                fsAction.set_enabled(mode == WindowMode.WindowMode.PREVIEW);
+                let canFullscreen = Global.modeController.getCanFullscreen();
+                fsAction.set_enabled(canFullscreen);
             }));
         this.application.add_action(fsAction);
 
@@ -113,13 +121,18 @@ Application.prototype = {
         this.application.add_action(viewAsAction);
 
 	let menu = new Gio.Menu();
-        menu.append(_("Fullscreen"), 'app.fullscreen');
-	menu.append(_("Quit"), 'app.quit');
 
         let viewAs = new Gio.Menu();
         viewAs.append(_("Grid"), 'app.view-as::icon');
         viewAs.append(_("List"), 'app.view-as::list');
-        menu.prepend_section(_("View as"), viewAs);
+        menu.append_section(_("View as"), viewAs);
+
+        let docActions = new Gio.Menu();
+        docActions.append(_("Fullscreen"), 'app.fullscreen');
+        menu.append_section(null, docActions);
+
+        menu.append(_("About Documents"), 'app.about');
+        menu.append(_("Quit"), 'app.quit');
 
 	this.application.set_app_menu(menu);
     },
@@ -163,6 +176,7 @@ Application.prototype = {
         Global.trackerController = new TrackerController.TrackerController();
         Global.selectionController = new Selections.SelectionController();
         Global.modeController = new WindowMode.ModeController();
+        Global.notificationManager = new Notifications.NotificationManager();
 
         this._initMenus();
         this._mainWindow = new MainWindow.MainWindow(this.application);
