@@ -630,14 +630,14 @@ LocalDocument.prototype = {
             this.typeDescription = Gio.content_type_get_description(this.mimeType);
     },
 
-    loadPreview: function(cancellable, callback) {
+    load: function(cancellable, callback) {
         Gd.pdf_loader_load_uri_async(this.uri, cancellable, Lang.bind(this,
             function(source, res) {
                 try {
                     let document = Gd.pdf_loader_load_uri_finish(res);
-                    callback(document);
+                    callback(this, document, null);
                 } catch (e) {
-                    Global.errorHandler.addLoadError(this, e);
+                    callback(this, null, e);
                 }
             }));
     },
@@ -711,7 +711,7 @@ GoogleDocument.prototype = {
                  }));
     },
 
-    loadPreview: function(cancellable, callback) {
+    load: function(cancellable, callback) {
         this._createGDataEntry(cancellable, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
@@ -720,10 +720,10 @@ GoogleDocument.prototype = {
                         function(source, res) {
                             try {
                                 let document = Gd.pdf_loader_load_uri_finish(res);
-                                callback(document);
+                                callback(this, document, null);
                             } catch (e) {
                                 // report the outmost error only
-                                Global.errorHandler.addLoadError(this, exception);
+                                callback(this, null, exception);
                                 return;
                             }
                         }));
@@ -736,9 +736,9 @@ GoogleDocument.prototype = {
                         function(source, res) {
                             try {
                                 let document = Gd.pdf_loader_load_entry_finish(res);
-                                callback(document);
+                                callback(this, document, null);
                             } catch (e) {
-                                Global.errorHandler.addLoadError(this, e);
+                                callback(this, null, e);
                             }
                         }));
             }));
@@ -915,14 +915,6 @@ DocumentManager.prototype = {
     }
 };
 
-const ModelColumns = {
-    URN: 0,
-    TITLE: 1,
-    AUTHOR: 2,
-    ICON: 3,
-    MTIME: 4
-};
-
 function DocumentModel() {
     this._init();
 }
@@ -930,7 +922,7 @@ function DocumentModel() {
 DocumentModel.prototype = {
     _init: function() {
         this.model = Gd.create_list_store();
-        this.model.set_sort_column_id(ModelColumns.MTIME,
+        this.model.set_sort_column_id(Gd.MainColumns.MTIME,
                                       Gtk.SortType.DESCENDING);
     },
 
@@ -942,7 +934,7 @@ DocumentModel.prototype = {
         let iter = this.model.append();
 
         Gd.store_set(this.model, iter,
-                     doc.id,
+                     doc.id, doc.uri,
                      doc.name, doc.author,
                      doc.pixbuf, doc.mtime);
 
@@ -958,7 +950,7 @@ DocumentModel.prototype = {
                 let objectIter = this.model.get_iter(objectPath)[1];
                 if (objectIter)
                     Gd.store_set(this.model, iter,
-                                 doc.id,
+                                 doc.id, doc.uri,
                                  doc.name, doc.author,
                                  doc.pixbuf, doc.mtime);
             }));
@@ -967,9 +959,9 @@ DocumentModel.prototype = {
     documentRemoved: function(doc) {
         this.model.foreach(Lang.bind(this,
             function(model, path, iter) {
-                let urn = model.get_value(iter, ModelColumns.URN);
+                let id = model.get_value(iter, Gd.MainColumns.ID);
 
-                if (urn == doc.id) {
+                if (id == doc.id) {
                     this.model.remove(iter);
                     return true;
                 }
