@@ -27,6 +27,8 @@ const Global = imports.global;
 const LoadMore = imports.loadMore;
 const MainToolbar = imports.mainToolbar;
 const Preview = imports.preview;
+const Searchbar = imports.searchbar;
+const Selections = imports.selections;
 const SpinnerBox = imports.spinnerBox;
 const Tweener = imports.util.tweener;
 const View = imports.view;
@@ -58,31 +60,39 @@ ViewEmbed.prototype  = {
         this._scrolledWinView = null;
         this._scrolledWinPreview = null;
 
+        this._filter = new Gd.FullscreenFilter();
+        this._filter.connect('motion-event', Lang.bind(this, this._fullscreenMotionHandler));
+
         // the embed is a vertical ClutterBox
-        this._layout = new Clutter.BoxLayout({ vertical: true });
-        this.actor = new Clutter.Box({ layout_manager: this._layout });
+        this._overlayLayout = new Clutter.BinLayout();
+        this.actor = new Clutter.Box({ layout_manager: this._overlayLayout });
+
+        this._contentsLayout = new Clutter.BoxLayout({ vertical: true });
+        this._contentsActor = new Clutter.Box({ layout_manager: this._contentsLayout });
+        this._overlayLayout.add(this._contentsActor,
+            Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
 
         // pack the toolbar
         this._toolbar = new MainToolbar.MainToolbar();
-        this.actor.add_actor(this._toolbar.actor);
-        this._layout.set_fill(this._toolbar.actor, true, false);
+        this._contentsActor.add_actor(this._toolbar.actor);
+        this._contentsLayout.set_fill(this._toolbar.actor, true, false);
 
         // pack the main GtkNotebook and a spinnerbox in a BinLayout, so that
         // we can easily bring them front/back
-        this._embedLayout = new Clutter.BinLayout();
-        this._embedActor = new Clutter.Box({ layout_manager: this._embedLayout });
-        this._layout.set_expand(this._embedActor, true);
-        this._layout.set_fill(this._embedActor, true, true);
-        this.actor.add_actor(this._embedActor);
+        this._viewLayout = new Clutter.BinLayout();
+        this._viewActor = new Clutter.Box({ layout_manager: this._viewLayout });
+        this._contentsLayout.set_expand(this._viewActor, true);
+        this._contentsLayout.set_fill(this._viewActor, true, true);
+        this._contentsActor.add_actor(this._viewActor);
 
         this._notebook = new Gtk.Notebook({ show_tabs: false,
                                             show_border: false });
         this._notebook.show();
         this._notebookActor = new GtkClutter.Actor({ contents: this._notebook });
-        this._embedLayout.add(this._notebookActor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
+        this._viewLayout.add(this._notebookActor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
 
         this._spinnerBox = new SpinnerBox.SpinnerBox();
-        this._embedLayout.add(this._spinnerBox.actor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
+        this._viewLayout.add(this._spinnerBox.actor, Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
         this._spinnerBox.actor.lower_bottom();
 
         // also pack a white background to use for spotlights between window modes
@@ -91,10 +101,50 @@ ViewEmbed.prototype  = {
                                                                 blue: 255,
                                                                 green: 255,
                                                                 alpha: 255 }) });
-        this._embedLayout.add(this._background,
+        this._viewLayout.add(this._background,
             Clutter.BinAlignment.FILL, Clutter.BinAlignment.FILL);
         this._background.lower_bottom();
 
+        // create the dropdown for the search bar, it's hidden by default
+        this._dropdownBox = new Searchbar.Dropdown();
+        this._overlayLayout.add(this._dropdownBox.actor,
+            Clutter.BinAlignment.CENTER, Clutter.BinAlignment.START);
+
+        // create the OSD toolbar for selected items, it's hidden by default
+        this._selectionToolbar = new Selections.SelectionToolbar();
+        let widthConstraint =
+            new Clutter.BindConstraint({ source: this._contentsActor,
+                                         coordinate: Clutter.BindCoordinate.WIDTH,
+                                         offset: - 300 });
+        this._selectionToolbar.actor.add_constraint(widthConstraint);
+        this._selectionToolbar.actor.connect('notify::width', Lang.bind(this,
+            function() {
+                let width = this._contentsActor.width;
+                let offset = 300;
+
+                if (width > 1000)
+                    offset += (width - 1000);
+                else if (width < 600)
+                    offset -= (600 - width);
+
+                widthConstraint.offset = - offset;
+            }));
+
+        this._selectionToolbar.actor.add_constraint(
+            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.X_AXIS,
+                                          source: this._contentsActor,
+                                          factor: 0.50 }));
+        this._selectionToolbar.actor.add_constraint(
+            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.Y_AXIS,
+                                          source: this._contentsActor,
+                                          factor: 0.95 }));
+        this._overlayLayout.add(this._selectionToolbar.actor,
+            Clutter.BinAlignment.FIXED, Clutter.BinAlignment.FIXED);
+
+        // pack the OSD notification actor
+        this._viewLayout.add(Global.notificationManager.actor,
+            Clutter.BinAlignment.CENTER, Clutter.BinAlignment.START);
+
         Global.errorHandler.connect('load-error',
                                     Lang.bind(this, this._onLoadError));
 
@@ -121,12 +171,20 @@ ViewEmbed.prototype  = {
     },
 
     _onFullscreenChanged: function(controller, fullscreen) {
-        this._motionTimeoutId = 0;
+        if (this._motionTimeoutId != 0) {
+            Mainloop.source_remove(this._motionTimeoutId);
+            this._motionTimeoutId = 0;
+        }
 
         if (fullscreen)
-            this._createFullscreenToolbar();
+            this._filter.start();
         else
+            this._filter.stop();
+
+        if (!fullscreen) {
             this._destroyFullscreenToolbar();
+            this._destroyPreviewEmbed();
+        }
 
         Gtk.Settings.get_default().gtk_application_prefer_dark_theme = fullscreen;
         this._toolbar.widget.visible = !fullscreen;
@@ -136,13 +194,14 @@ ViewEmbed.prototype  = {
         this._fsToolbar = new MainToolbar.FullscreenToolbar();
         this._fsToolbar.setModel(this._docModel);
 
-        Global.stage.add_actor(this._fsToolbar.actor);
+        this._overlayLayout.add(this._fsToolbar.actor,
+            Clutter.BinAlignment.FIXED, Clutter.BinAlignment.FIXED);
 
         let vScrollbar = this._scrolledWinPreview.get_vscrollbar();
 
         let sizeConstraint = new Clutter.BindConstraint
             ({ coordinate: Clutter.BindCoordinate.WIDTH,
-               source: Global.stage,
+               source: this.actor,
                offset: (vScrollbar.get_visible() ?
                         (- (vScrollbar.get_preferred_width()[1])) : 0 ) });
 
@@ -161,6 +220,13 @@ ViewEmbed.prototype  = {
         this._fsToolbar = null;
     },
 
+    _destroyPreviewEmbed: function() {
+        if (this._previewEmbed) {
+            this._previewEmbed.actor.destroy();
+            this._previewEmbed = null;
+        }
+    },
+
     _moveOutBackground: function() {
         Tweener.addTween(this._background, { opacity: 0,
                                              time: 0.20,
@@ -231,39 +297,41 @@ ViewEmbed.prototype  = {
         this._spinnerBox.moveInDelayed(_PDF_LOADER_TIMEOUT);
 
         this._loaderCancellable = new Gio.Cancellable();
-        doc.loadPreview(this._loaderCancellable, Lang.bind(this, this._onDocumentLoaded));
+        doc.load(this._loaderCancellable, Lang.bind(this, this._onDocumentLoaded));
     },
 
-    _onDocumentLoaded: function(document) {
-        this._loaderCancellable = null;
-        this._docModel = EvView.DocumentModel.new_with_document(document);
+    _onDocumentLoaded: function(doc, evDoc, error) {
+        if (!evDoc) {
+            Global.errorHandler.addLoadError(doc, error);
+            return;
+        }
+
+        this._docModel = EvView.DocumentModel.new_with_document(evDoc);
+        this._toolbar.setModel(this._docModel);
 
         this._spinnerBox.moveOut();
         Global.modeController.setCanFullscreen(true);
         this._preview = new Preview.PreviewView(this._docModel);
-
-        if (this._fsToolbar)
-            this._fsToolbar.setModel(this._docModel);
-
-        this._toolbar.setModel(this._docModel);
-
-        this._preview.widget.connect('motion-notify-event',
-                                     Lang.bind(this, this._fullscreenMotionHandler));
+        this._previewEmbed = new Preview.PreviewEmbed(this._docModel,
+            this._overlayLayout, this._contentsActor);
+        this._createFullscreenToolbar();
 
         this._scrolledWinPreview.add(this._preview.widget);
         this._preview.widget.grab_focus();
     },
 
-    _fullscreenMotionHandler: function(widget, event) {
+    _fullscreenMotionHandler: function() {
         if (!Global.modeController.getFullscreen())
-            return false;
+            return;
 
         // if we were idle fade in the toolbar, otherwise reset
         // the timeout
-        if (this._motionTimeoutId == 0)
+        if (this._motionTimeoutId == 0) {
             this._fsToolbar.show();
-        else
+            this._previewEmbed.thumbBar.show();
+        } else {
             Mainloop.source_remove(this._motionTimeoutId);
+        }
 
         this._motionTimeoutId = Mainloop.timeout_add_seconds
             (_FULLSCREEN_TOOLBAR_TIMEOUT, Lang.bind(this,
@@ -273,10 +341,10 @@ ViewEmbed.prototype  = {
                     if (this._fsToolbar)
                         this._fsToolbar.hide();
 
+                    this._previewEmbed.thumbBar.hide();
+
                     return false;
             }));
-
-        return false;
     },
 
     _prepareForOverview: function() {
