@@ -27,6 +27,7 @@ let documentManager = null;
 let errorHandler = null;
 let goaClient = null;
 let modeController = null;
+let notificationManager = null;
 let offsetController = null;
 let queryBuilder = null;
 let searchCategoryManager = null;
@@ -35,6 +36,5 @@ let searchMatchManager = null;
 let searchTypeManager = null;
 let selectionController = null;
 let settings = null;
-let stage = null;
 let sourceManager = null;
 let trackerController = null;
