@@ -28,6 +28,7 @@ const GtkClutter = imports.gi.GtkClutter;
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
+const Config = imports.config;
 const Embed = imports.embed;
 const Global = imports.global;
 const Searchbar = imports.searchbar;
@@ -55,7 +56,7 @@ MainWindow.prototype = {
         this.window.add(this._clutterEmbed);
         this._clutterEmbed.show();
 
-        Global.stage = this._clutterEmbed.get_stage();
+        let stage = this._clutterEmbed.get_stage();
 
         Global.modeController.setWindowMode(WindowMode.WindowMode.OVERVIEW);
 
@@ -98,9 +99,9 @@ MainWindow.prototype = {
         this._clutterBox = new Clutter.Box({ layout_manager: this._clutterBoxLayout });
         this._clutterBox.add_constraint(
             new Clutter.BindConstraint({ coordinate: Clutter.BindCoordinate.SIZE,
-                                         source: Global.stage }));
+                                         source: stage }));
 
-        Global.stage.add_actor(this._clutterBox);
+        stage.add_actor(this._clutterBox);
 
         // first child: searchbar filling the X axis
         this._searchbar = new Searchbar.Searchbar();
@@ -111,48 +112,6 @@ MainWindow.prototype = {
         this._clutterBox.add_actor(this._embed.actor);
         this._clutterBoxLayout.set_expand(this._embed.actor, true);
         this._clutterBoxLayout.set_fill(this._embed.actor, true, true);
-
-        // create the dropdown for the search bar, it's hidden by default
-        this._dropdownBox = new Searchbar.Dropdown();
-        this._dropdownBox.actor.add_constraint(
-            new Clutter.BindConstraint({ source: this._embed.actor,
-                                         coordinate: Clutter.BindCoordinate.Y }));
-        this._dropdownBox.actor.add_constraint(
-            new Clutter.AlignConstraint({ source: this._embed.actor,
-                                          align_axis: Clutter.AlignAxis.X_AXIS,
-                                          factor: 0.50 }));
-        Global.stage.add_actor(this._dropdownBox.actor);
-
-        // create the OSD toolbar for selected items, it's hidden by default
-        this._selectionToolbar = new Selections.SelectionToolbar();
-        let widthConstraint =
-            new Clutter.BindConstraint({ source: this._embed.actor,
-                                         coordinate: Clutter.BindCoordinate.WIDTH,
-                                         offset: - 300 });
-        this._selectionToolbar.actor.add_constraint(widthConstraint);
-        this._selectionToolbar.actor.connect('notify::width', Lang.bind(this,
-            function() {
-                let width = this._embed.actor.width;
-                let offset = 300;
-
-                if (width > 1000)
-                    offset += (width - 1000);
-                else if (width < 600)
-                    offset -= (600 - width);
-
-                widthConstraint.offset = - offset;
-            }));
-
-        this._selectionToolbar.actor.add_constraint(
-            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.X_AXIS,
-                                          source: this._embed.actor,
-                                          factor: 0.50 }));
-        this._selectionToolbar.actor.add_constraint(
-            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.Y_AXIS,
-                                          source: this._embed.actor,
-                                          factor: 0.95 }));
-
-        Global.stage.add_actor(this._selectionToolbar.actor);
     },
 
     _saveWindowGeometry: function() {
@@ -257,7 +216,16 @@ MainWindow.prototype = {
 
         if (!Global.searchController.getSearchIn()) {
             Global.searchController.deliverEvent(event);
-            return Global.searchController.getEventHandled();
+            let handled = Global.searchController.getEventHandled();
+
+            if (handled)
+                return true;
+        }
+
+        if (Global.selectionController.getSelectionMode() &&
+            keyval == Gdk.KEY_Escape) {
+            Global.selectionController.setSelectionMode(false);
+            return true;
         }
 
         return false;
@@ -274,5 +242,31 @@ MainWindow.prototype = {
         this._saveWindowGeometry();
 
         return false;
+    },
+
+    showAbout: function() {
+        let aboutDialog = new Gtk.AboutDialog();
+
+        aboutDialog.artists = [ 'Jakub Steiner <jimmac@gmail.com>' ];
+        aboutDialog.authors = [ 'Cosimo Cecchi <cosimoc@gnome.org>',
+                                'Florian M' + String.fromCharCode(0x00FC) + 'llner <fmuellner@gnome.org>',
+                                'William Jon McCann <william.jon.mccann@gmail.com>' ];
+        aboutDialog.translator_credits = _("translator-credits");
+        aboutDialog.program_name = _("GNOME Documents");
+        aboutDialog.comments = _("A document manager application");
+        aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2011' + String.fromCharCode(0x2013) + '2012 Red Hat, Inc.';
+        aboutDialog.license_type = Gtk.License.GPL_2_0;
+        aboutDialog.logo_icon_name = 'gnome-documents';
+        aboutDialog.version = Config.PACKAGE_VERSION;
+        aboutDialog.website = 'http://live.gnome.org/GnomeDocuments';
+        aboutDialog.wrap_license = true;
+
+        aboutDialog.modal = true;
+        aboutDialog.transient_for = this.window;
+
+        aboutDialog.show();
+        aboutDialog.connect('response', function() {
+            aboutDialog.destroy();
+        });
     }
 };
