@@ -202,6 +202,8 @@ SearchMatchManager.prototype = {
     __proto__: Manager.BaseManager.prototype,
 
     _init: function() {
+        // Translators: this is a verb that refers to "All", "Title" and "Author",
+        // as in "Match All", "Match Title" and "Match Author"
         Manager.BaseManager.prototype._init.call(this, _("Match"));
 
         this.addItem(new SearchMatch({ id: SearchMatchStock.ALL,
@@ -415,6 +417,8 @@ Searchbar.prototype = {
             Lang.bind(this, this._onActiveTypeChanged));
         this._searchMatchId = Global.searchMatchManager.connect('active-changed',
             Lang.bind(this, this._onActiveMatchChanged));
+        this._collectionId = Global.collectionManager.connect('active-changed',
+            Lang.bind(this, this._onActiveCollectionChanged));
 
         this._onActiveSourceChanged();
         this._onActiveTypeChanged();
@@ -477,7 +481,7 @@ Searchbar.prototype = {
                 function() {
                     this._searchEntryTimeout = 0;
 
-                    let currentText = this._searchEntry.get_text();
+                    let currentText = this._searchEntry.get_text().toLowerCase();
                     Global.searchController.setString(currentText);
             }));
         }));
@@ -497,6 +501,16 @@ Searchbar.prototype = {
         this.widget.show_all();
     },
 
+    _onActiveCollectionChanged: function() {
+        let searchType = Global.sourceManager.getActiveItem();
+
+        if (Global.searchController.getString() != '' ||
+            searchType.id != 'all') {
+            Global.searchTypeManager.setActiveItemById('all');
+            this._searchEntry.set_text('');
+        }
+    },
+
     destroy: function() {
         if (this._searchFocusId != 0) {
             Global.searchController.disconnect(this._searchFocusId);
@@ -528,6 +542,11 @@ Searchbar.prototype = {
             this._searchDropdownId = 0;
         }
 
+        if (this._collectionId != 0) {
+            Global.searchController.disconnect(this._collectionId);
+            this._collectionId = 0;
+        }
+
         this.widget.destroy();
     },
 
