@@ -19,6 +19,7 @@
  *
  */
 
+const EvView = imports.gi.EvinceView;
 const Gd = imports.gi.Gd;
 const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
@@ -29,6 +30,7 @@ const _ = imports.gettext.gettext;
 const Documents = imports.documents;
 const Global = imports.global;
 const Manager = imports.manager;
+const Notifications = imports.notifications;
 const Query = imports.query;
 const Tweener = imports.util.tweener;
 const Utils = imports.utils;
@@ -97,7 +99,7 @@ const OrganizeCollectionState = {
     NORMAL: 0,
     ACTIVE: 1 << 0,
     INCONSISTENT: 1 << 1,
-    INSENSITIVE: 1 << 2
+    HIDDEN: 1 << 2
 };
 
 function FetchCollectionStateForSelectionJob() {
@@ -141,7 +143,17 @@ FetchCollectionStateForSelectionJob.prototype = {
 
             let found = false;
             let notFound = false;
-            let sameResource = true;
+            let hidden = false;
+
+            // if the only object we are fetching collection state for is a
+            // collection itself, hide this if it's the same collection.
+            if (Object.keys(this._collectionsForItems).length == 1) {
+                let itemIdx = Object.keys(this._collectionsForItems)[0];
+                let item = Global.documentManager.getItemById(itemIdx);
+
+                if (item.id == collection.id)
+                    hidden = true;
+            }
 
             for (itemIdx in this._collectionsForItems) {
                 let item = Global.documentManager.getItemById(itemIdx);
@@ -155,7 +167,7 @@ FetchCollectionStateForSelectionJob.prototype = {
 
                 if ((item.resourceUrn != collection.resourceUrn) &&
                     (collection.identifier.indexOf(Query.LOCAL_COLLECTIONS_IDENTIFIER) == -1)) {
-                    sameResource = false;
+                    hidden = true;
                 }
             }
 
@@ -168,8 +180,8 @@ FetchCollectionStateForSelectionJob.prototype = {
                 // if all items are part of this collection...
                 state |= OrganizeCollectionState.ACTIVE;
 
-            if (!sameResource)
-                state |= OrganizeCollectionState.INSENSITIVE;
+            if (hidden)
+                state |= OrganizeCollectionState.HIDDEN;
 
             collectionState[collIdx] = state;
         }
@@ -223,6 +235,10 @@ SetCollectionForSelectionJob.prototype = {
         let urns = Global.selectionController.getSelection();
         urns.forEach(Lang.bind(this,
             function(urn) {
+                // never add a collection to itself!!
+                if (urn == this._collectionUrn)
+                    return;
+
                 let query = Global.queryBuilder.buildSetCollectionQuery(urn,
                     this._collectionUrn, this._setting);
                 this._runningJobs++;
@@ -356,6 +372,9 @@ OrganizeCollectionModel.prototype = {
             let item = Global.collectionManager.getItemById(idx);
             let iter = null;
 
+            if ((collectionState[item.id] & OrganizeCollectionState.HIDDEN) != 0)
+                continue;
+
             iter = this._findCollectionIter(item);
             if (!iter)
                 iter = this.model.append();
@@ -437,9 +456,13 @@ OrganizeCollectionView.prototype = {
         this._rendererText = new Gtk.CellRendererText();
         this._viewCol.pack_start(this._rendererText, true);
         this._viewCol.add_attribute(this._rendererText,
-                                    'text', Manager.BaseModelColumns.NAME);
-        this._viewCol.set_cell_data_func(this._rendererText,
-                                         Lang.bind(this, this._textCellFunc));
+                                    'text', OrganizeModelColumns.NAME);
+
+        this._rendererDetail = new Gd.StyledTextRenderer({ xpad: 16 });
+        this._rendererDetail.add_class('dim-label');
+        this._viewCol.pack_start(this._rendererDetail, false);
+        this._viewCol.set_cell_data_func(this._rendererDetail,
+                                         Lang.bind(this, this._detailCellFunc));
 
         this._rendererText.connect('edited', Lang.bind(this, this._onTextEdited));
         this._rendererText.connect('editing-canceled', Lang.bind(this, this._onTextEditCanceled));
@@ -518,12 +541,19 @@ OrganizeCollectionView.prototype = {
 
         cell.active = (state & OrganizeCollectionState.ACTIVE);
         cell.inconsistent = (state & OrganizeCollectionState.INCONSISTENT);
-        cell.sensitive = !(state & OrganizeCollectionState.INSENSITIVE);
     },
 
-    _textCellFunc: function(col, cell, model, iter) {
-        let state = model.get_value(iter, OrganizeModelColumns.STATE);
-        cell.sensitive = !(state & OrganizeCollectionState.INSENSITIVE);
+    _detailCellFunc: function(col, cell, model, iter) {
+        let id = model.get_value(iter, OrganizeModelColumns.ID);
+        let item = Global.collectionManager.getItemById(id);
+
+        if (item && item.identifier.indexOf(Query.LOCAL_COLLECTIONS_IDENTIFIER) == -1) {
+            cell.text = Global.sourceManager.getItemById(item.resourceUrn).name;
+            cell.visible = true;
+        } else {
+            cell.text = '';
+            cell.visible = false;
+        }
     },
 
     addCollection: function() {
@@ -649,6 +679,11 @@ SelectionToolbar.prototype = {
         this._leftBox.add(this._toolbarFavorite);
         this._toolbarFavorite.connect('clicked', Lang.bind(this, this._onToolbarFavorite));
 
+        this._toolbarPrint = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'printer-symbolic',
+                                                                      pixel_size: 32 })});
+        this._leftBox.add(this._toolbarPrint);
+        this._toolbarPrint.connect('clicked', Lang.bind(this, this._onToolbarPrint));
+
         this._separator = new Gtk.SeparatorToolItem({ draw: false });
         this._separator.set_expand(true);
         this.widget.insert(this._separator, -1);
@@ -726,6 +761,7 @@ SelectionToolbar.prototype = {
         let favCount = 0;
         let showFavorite = true;
         let canTrash = true;
+        let showPrint = false;
 
         this._insideRefresh = true;
 
@@ -747,6 +783,17 @@ SelectionToolbar.prototype = {
 
         showFavorite &= ((favCount == 0) || (favCount == selection.length));
 
+        if (selection.length == 1) {
+            let urn = selection[0];
+            if (!Global.collectionManager.getItemById(urn))
+                showPrint = true;
+        }
+
+        if (showPrint)
+            this._toolbarPrint.show_all();
+        else
+            this._toolbarPrint.hide();
+
         // if we're showing the favorite icon, also show the separator
         this._separator.set_visible(showFavorite);
 
@@ -843,6 +890,28 @@ SelectionToolbar.prototype = {
             }));
     },
 
+    _onToolbarPrint: function(widget) {
+        let selection = Global.selectionController.getSelection();
+
+        if (selection.length != 1)
+            return;
+
+        let doc = Global.documentManager.getItemById(selection[0]);
+        doc.load(null, Lang.bind(this,
+            function(doc, evDoc, error) {
+                if (!evDoc) {
+                    // TODO: handle error here!
+                    return;
+                }
+
+                let printOp = EvView.PrintOperation.new(evDoc);
+                let printNotification = new Notifications.PrintNotification(printOp, doc);
+
+                let toplevel = this.widget.get_toplevel();
+                printOp.run(toplevel);
+            }));
+    },
+
     _fadeIn: function() {
         if (this.actor.opacity != 0)
             return;
