@@ -21,6 +21,8 @@
 
 const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
+const Gettext = imports.gettext;
+const GLib = imports.gi.GLib;
 const Gtk = imports.gi.Gtk;
 const _ = imports.gettext.gettext;
 
@@ -151,24 +153,71 @@ View.prototype = {
         let listWidget = this.widget.get_generic_view();
 
         let typeRenderer =
-            new Gtk.CellRendererText({ xpad: 16 });
+            new Gd.StyledTextRenderer({ xpad: 16 });
+        typeRenderer.add_class('dim-label');
         listWidget.add_renderer(typeRenderer, Lang.bind(this,
             function(col, cell, model, iter) {
-                let urn = model.get_value(iter, Documents.ModelColumns.URN);
-                let doc = Global.documentManager.getItemById(urn);
+                let id = model.get_value(iter, Gd.MainColumns.ID);
+                let doc = Global.documentManager.getItemById(id);
 
                 typeRenderer.text = doc.typeDescription;
             }));
 
         let whereRenderer =
-            new Gtk.CellRendererText({ xpad: 8 });
+            new Gd.StyledTextRenderer({ xpad: 16 });
+        whereRenderer.add_class('dim-label');
         listWidget.add_renderer(whereRenderer, Lang.bind(this,
             function(col, cell, model, iter) {
-                let urn = model.get_value(iter, Documents.ModelColumns.URN);
-                let doc = Global.documentManager.getItemById(urn);
+                let id = model.get_value(iter, Gd.MainColumns.ID);
+                let doc = Global.documentManager.getItemById(id);
 
                 whereRenderer.text = doc.sourceName;
             }));
+
+        let dateRenderer =
+            new Gtk.CellRendererText({ xpad: 32 });
+        listWidget.add_renderer(dateRenderer, Lang.bind(this,
+            function(col, cell, model, iter) {
+                let id = model.get_value(iter, Gd.MainColumns.ID);
+                let doc = Global.documentManager.getItemById(id);
+                let DAY = 86400000000;
+
+                let now = GLib.DateTime.new_now_local();
+                let mtime = GLib.DateTime.new_from_unix_local(doc.mtime);
+                let difference = now.difference(mtime);
+                let days = Math.floor(difference / DAY);
+                let weeks = Math.floor(difference / (7 * DAY));
+                let months = Math.floor(difference / (30 * DAY));
+                let years = Math.floor(difference / (365 * DAY));
+
+                if (difference < DAY) {
+                    dateRenderer.text = mtime.format('%X');
+                } else if (difference < 2 * DAY) {
+                    dateRenderer.text = _("Yesterday");
+                } else if (difference < 7 * DAY) {
+                    dateRenderer.text = Gettext.ngettext("%d day ago",
+                                                         "%d days ago",
+                                                         days).format(days);
+                } else if (difference < 14 * DAY) {
+                    dateRenderer.text = _("Last week");
+                } else if (difference < 28 * DAY) {
+                    dateRenderer.text = Gettext.ngettext("%d week ago",
+                                                         "%d weeks ago",
+                                                         weeks).format(weeks);
+                } else if (difference < 60 * DAY) {
+                    dateRenderer.text = _("Last month");
+                } else if (difference < 360 * DAY) {
+                    dateRenderer.text = Gettext.ngettext("%d month ago",
+                                                         "%d months ago",
+                                                         months).format(months);
+                } else if (difference < 730 * DAY) {
+                    dateRenderer.text = _("Last year");
+                } else {
+                    dateRenderer.text = Gettext.ngettext("%d year ago",
+                                                         "%d years ago",
+                                                         years).format(years);
+                }
+            }));
     },
 
     _onViewTypeChanged: function() {
@@ -228,15 +277,15 @@ View.prototype = {
         let first = true;
         this._treeModel.foreach(Lang.bind(this,
             function(model, path, iter) {
-                let urn = this._treeModel.get_value(iter, Documents.ModelColumns.URN);
-                let urnIndex = selected.indexOf(urn);
+                let id = this._treeModel.get_value(iter, Gd.MainColumns.ID);
+                let idIndex = selected.indexOf(id);
 
-                if (urnIndex != -1) {
-                    generic.select_path(path);
-                    selected.splice(urnIndex, 1);
+                if (idIndex != -1) {
+                    this._treeModel.set_value(iter, Gd.MainColumns.SELECTED, true);
+                    selected.splice(idIndex, 1);
 
                     if (first) {
-                        generic.scrollToPath(path);
+                        generic.scroll_to_path(path);
                         first = false;
                     }
                 }
@@ -254,10 +303,8 @@ View.prototype = {
     },
 
     _onSelectionChanged: function() {
-        let generic = this.widget.get_generic_view();
-
         // update the selection on the controller when the view signals a change
-        let selectedURNs = Utils.getURNsFromPaths(generic.get_selection(),
+        let selectedURNs = Utils.getURNsFromPaths(this.widget.get_selection(),
                                                   this._treeModel);
         Global.selectionController.setSelection(selectedURNs);
     }
